@@ -26,7 +26,7 @@ from tastypie.serializers import Serializer
 from tastypie.utils import trailing_slash
 from tastypie.validation import Validation
 
-from oppia.api.serializers import PrettyJSONSerializer, CourseJSONSerializer, TagJSONSerializer, UserJSONSerializer
+from oppia.api.serializers import PrettyJSONSerializer, CourseJSONSerializer, UserJSONSerializer
 from oppia.models import Activity, Section, Tracker, Course, CourseDownload, Media, Schedule, ActivitySchedule, Cohort, Tag, CourseTag
 from oppia.models import Points, Award, Badge, UserProfile
 from oppia.profile.forms import RegisterForm
@@ -320,7 +320,7 @@ class CourseResource(ModelResource):
         queryset = Course.objects.all()
         resource_name = 'course'
         allowed_methods = ['get']
-        fields = ['id', 'title', 'version', 'shortname','is_draft']
+        fields = ['id', 'title', 'version', 'shortname','is_draft','description']
         authentication = ApiKeyAuthentication()
         authorization = ReadOnlyAuthorization() 
         serializer = CourseJSONSerializer()
@@ -397,6 +397,11 @@ class CourseResource(ModelResource):
         # make sure title is shown as json object (not string representation of one)
         bundle.data['title'] = json.loads(bundle.data['title'])
         
+        try:
+            bundle.data['description'] = json.loads(bundle.data['description'])
+        except TypeError: 
+            pass
+        
         course = Course.objects.get(pk=bundle.obj.pk)
         schedule = course.get_default_schedule()
         cohort = Cohort.member_now(course,bundle.request.user)
@@ -444,18 +449,17 @@ class TagResource(ModelResource):
         queryset = Tag.objects.all()
         resource_name = 'tag'
         allowed_methods = ['get']
-        fields = ['id','name']
+        fields = ['id','name', 'description', 'highlight', 'icon', 'order_priority']
         authentication = ApiKeyAuthentication()
         authorization = ReadOnlyAuthorization() 
         always_return_data = True
         include_resource_uri = False
-        serializer = TagJSONSerializer()
        
     def get_object_list(self,request):
         if request.user.is_staff:
-            return Tag.objects.filter(courses__isnull=False, coursetag__course__is_archived=False).distinct().order_by("name")
+            return Tag.objects.filter(courses__isnull=False, coursetag__course__is_archived=False).distinct().order_by('-order_priority', 'name')
         else:
-            return Tag.objects.filter(courses__isnull=False, coursetag__course__is_archived=False,coursetag__course__is_draft=False).distinct().order_by("name")
+            return Tag.objects.filter(courses__isnull=False, coursetag__course__is_archived=False,coursetag__course__is_draft=False).distinct().order_by('-order_priority', 'name')
         
     def prepend_urls(self):
         return [
@@ -494,7 +498,17 @@ class TagResource(ModelResource):
         else:
             count = tmp.filter(is_draft=False).count()
         return count
-        
+     
+    def dehydrate_icon(self,bundle):
+        if bundle.request.is_secure():
+            prefix = 'https://'
+        else:
+            prefix = 'http://'
+        if bundle.data['icon'] is not None:
+            return prefix + bundle.request.META['SERVER_NAME'] + bundle.data['icon'] 
+        else:
+            return None
+    
     def alter_list_data_to_serialize(self, request, data):
         if isinstance(data, dict):
             if 'objects' in data:
